@@ -19,7 +19,7 @@
 #include "tse3/FileBlockParser.h"
 #include "tse3/Mutex.h"
 
-#include <strstream>
+#include <sstream>
 
 using namespace TSE3;
 
@@ -174,7 +174,7 @@ namespace
             virtual void parse(const std::string &line)
             {
                 int r, g, b;
-                std::istrstream si(line.c_str());
+                std::istringstream si(line);
                 si >> r;
                 si.ignore(1); // skip comma
                 si >> g;
@@ -209,7 +209,7 @@ namespace
                 }
                 else
                 {
-                    std::istrstream si(line.c_str());
+                    std::istringstream si(line);
                     si >> pr;
                 }
 
