@@ -21,7 +21,7 @@
 
 #include <map>
 #include <string>
-#include <strstream>
+#include <sstream>
 
 namespace TSE3
 {
@@ -264,7 +264,7 @@ namespace TSE3
             void parse(const std::string &data)
             {
                 int i;
-                std::istrstream si(data.c_str());
+                std::istringstream si(data);
                 si >> i;
                 (obj->*mfun)(i);
             }
@@ -300,7 +300,7 @@ namespace TSE3
             void parse(const std::string &data)
             {
                 int i;
-                std::istrstream si(data.c_str());
+                std::istringstream si(data);
                 si >> i;
                 (obj->*mfun)(i);
             }
