@@ -1,7 +1,7 @@
 /*
  * @(#)MidiFile.cpp 3.00 30 June 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -443,13 +443,7 @@ void MidiFileImportIterator::calculateLastClock()
 MidiFileImport::MidiFileImport(const std::string &fn, int v, std::ostream &o)
 : filename(fn), verbose(v), out(o), file(0), fileLastClock(-1)
 {
-#if __GLIBCPP__ < 20010615
-    // Sigh. Old non-compliant stdc++ headers
-    std::ifstream
-#else
-    std::basic_ifstream<unsigned char>
-#endif
-        in(filename.c_str(), std::ios::binary | std::ios::in);
+    std::ifstream in(filename.c_str(), std::ios::binary | std::ios::in);
     if (!in.good())
     {
         throw MidiFileImportError("Source MIDI file will not open.");
@@ -468,7 +462,11 @@ MidiFileImport::MidiFileImport(const std::string &fn, int v, std::ostream &o)
         throw MidiFileImportError("Out of memory loading MIDI file.");
     }
 
-    in.read(file, fileSize);
+    // OK, this is relatively evil, we're reading a char stream into
+    // an unsigned char buffer. However, we opened the file binary and now
+    // cross our fingers. We can't easily use a ifstream<unsigned char>
+    // since it's not instantiated by default in existing standard C++
+    in.read(reinterpret_cast<char*>(file), fileSize);
     if (in.gcount() != fileSize)
         throw MidiFileImportError("Error loading MIDI file.");
 
@@ -707,7 +705,7 @@ void MidiFileImport::loadMTrk(size_t &pos, Song *song, int mtrkNo)
     // Create a Part for this Phrase and place it in th Track
     Part *part = new Part();
     part->setStart(0);
-    part->setEnd(end);
+    part->setEnd(Clock::convert(end, filePPQN));
     part->setPhrase(phrase);
     track->insert(part);
     if (verbose >= 2) out << "    Part between: 0 and " << part->end() << "\n";
@@ -1053,6 +1051,22 @@ MidiFileExport::~MidiFileExport()
 
 void MidiFileExport::save(const std::string &filename, Song *s,
                           Progress *progress)
+{
+
+    std::ofstream out(filename.c_str(),
+                      std::ios::binary | std::ios::out | std::ios::trunc);
+    if (!out.good())
+    {
+        throw MidiFileExportError("Output MIDI file will not open.");
+    }
+
+    save(out, s, progress);
+
+    out.close();
+}
+
+
+void MidiFileExport::save(std::ostream &out, Song *s, Progress *progress)
 {
     if (verbose)
     {
@@ -1067,12 +1081,6 @@ void MidiFileExport::save(const std::string &filename, Song *s,
         progress->progressRange(0, song->size() + 2);
     }
 
-    std::ofstream out(filename.c_str(), std::ios::binary | std::ios::in);
-    if (!out.good())
-    {
-        throw MidiFileExportError("Output MIDI file will not open.");
-    }
-
     _size = 0;
 
     // Write MThd header chunk
