@@ -256,7 +256,7 @@ Mixer::~Mixer()
 
 void Mixer::command(MidiCommand mc)
 {
-    if (mc.port < noPorts)
+    if ((size_t)mc.port < noPorts)
     {
         mixerPorts[mc.port]->command(mc);
     }
