@@ -290,7 +290,7 @@ namespace TSE3
                 const p4_type       &p4;                                 // (*)
         };
 
-    };
+    }
 
     /**************************************************************************
      * Public Notifier framework API
@@ -367,7 +367,7 @@ namespace TSE3
              */
             typedef Listener<interface_type> listener_type;
 
-            friend class listener_type;
+            friend class Listener<interface_type>;
 
         protected:
 
@@ -602,7 +602,7 @@ namespace TSE3
                 if (notifiers.erase(notifier)) notifier->detach(this);
             }
 
-            friend class notifier_type;
+            friend class Notifier<interface_type>;
 
         protected:
 
