@@ -27,7 +27,7 @@
 #include "tse3/PhraseList.h"
 #include "tse3/Mutex.h"
 
-#include <strstream>
+#include <sstream>
 
 using namespace TSE3;
 
@@ -618,7 +618,7 @@ namespace
             virtual void parse(const std::string &data)
             {
                 int i;
-                std::istrstream si(data.c_str());
+                std::istringstream si(data);
                 si >> i;
                 (p->*mfun)(i);
             }
