@@ -22,7 +22,7 @@
 #include "tse3/Error.h"
 #include "tse3/Mutex.h"
 
-#include <strstream>
+#include <sstream>
 #include <algorithm>
 
 using namespace TSE3;
@@ -161,11 +161,10 @@ std::string PhraseList::newPhraseTitle(const std::string &baseName)
     int n = 1;
     do
     {
-        char buffer[10];
-        std::ostrstream o(buffer, 10);
-        o << " " << n << std::ends;
+        std::ostringstream o;
+        o << " " << n;
         title = baseName;
-        title.append(buffer);
+        title.append(o.str());
         ++n;
     }
     while (phrase(title));
@@ -240,7 +239,7 @@ namespace
                 int data2,   offData2   = 0;
                 int channel, offChannel = 0;
                 int port,    offPort    = 0;
-                std::istrstream si(line.c_str());
+                std::istringstream si(line);
                 si >> time;
                 si.ignore(1); // skip colon
                 si >> status;
