@@ -17,7 +17,7 @@
 #include "tse3/RepeatTrack.h"
 #include "tse3/FileBlockParser.h"
 
-#include <strstream>
+#include <sstream>
 
 using namespace TSE3;
 
@@ -220,7 +220,7 @@ namespace
             {
                 int time, repeat;
                 bool status = true;
-                std::istrstream si(line.c_str());
+                std::istringstream si(line);
                 si >> time;
                 si.ignore(1); // skip colon
                 si >> repeat;
