@@ -1,7 +1,7 @@
 /*
  * @(#)Song.cpp 3.00 26 May 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -240,8 +240,8 @@ void SongIterator::updateIterators(Clock c)
 
 void SongIterator::moveTo(Clock c)
 {
-    if (_tti)  _tti->moveTo(c);  // XXX I don't think the iterators
-    if (_tsti) _tsti->moveTo(c); //     will ever be deleted
+    if (_tti)  _tti->moveTo(c);
+    if (_tsti) _tsti->moveTo(c);
     if (_ksti) _ksti->moveTo(c);
     if (_rti)  _rti->moveTo(c);
     std::vector<PlayableIterator*>::iterator i = _ti.begin();
@@ -393,11 +393,13 @@ class TSE3::SongImpl
         bool                 repeat;
         Clock                from;
         Clock                to;
+        Clock                lastClock;
 
         SongImpl()
         : title("Title"), author("Author"),
           copyright("Copyright message"), date("Date"),
-          soloTrack(-1), repeat(false), from(0), to(Clock::PPQN*4)
+          soloTrack(-1), repeat(false), from(0), to(Clock::PPQN*4),
+          lastClock(0)
         {}
 };
 
@@ -756,23 +758,43 @@ PlayableIterator *Song::iterator(Clock index)
 
 
 Clock Song::lastClock() const
+{
+    return pimpl->lastClock;
+}
+
+
+void Song::recalculateLastClock() const
 {
     Impl::CritSec cs;
 
-    Clock lastClock = 0;
+    pimpl->lastClock = 0;
     std::vector<Track *>::const_iterator i = pimpl->tracks.begin();
     while (i != pimpl->tracks.end())
     {
-        if ((*i)->lastClock() > lastClock)
+        if ((*i)->lastClock() > pimpl->lastClock)
         {
-            lastClock = (*i)->lastClock();
+            pimpl->lastClock = (*i)->lastClock();
         }
         ++i;
     }
     // Should I include the TempoTrack?
     // Should I include the TimeSigTrack?
     // Should I include the KeySigTrack?
-    return lastClock;
+}
+
+
+void Song::Track_PartInserted(Track *track, Part *)
+{
+    if (track->lastClock() > pimpl->lastClock)
+    {
+        pimpl->lastClock = track->lastClock();
+    }
+}
+
+
+void Song::Track_PartRemoved(Track *, Part *)
+{
+    recalculateLastClock();
 }
 
 
