@@ -23,7 +23,7 @@
 #include "tse3/MidiFile.h"
 #include "tse3/TSE2MDL.h"
 
-#include <strstream>
+#include <sstream>
 #include <fstream>
 #include <memory>
 
@@ -135,17 +135,17 @@ void TSE3MDL::Header::load(std::istream &in, SerializableLoadInfo &info)
     {
         if (line.substr(0, 5).compare("PPQN:") == 0)
         {
-            std::istrstream si(line.c_str()+5);
+            std::istringstream si(line.c_str()+5);
             si >> info.PPQN;
         }
         else if (line.substr(0, 14).compare("Version-Major:") == 0)
         {
-            std::istrstream si(line.c_str()+14);
+            std::istringstream si(line.c_str()+14);
             si >> info.major;
         }
         else if (line.substr(0, 14).compare("Version-Minor:") == 0)
         {
-            std::istrstream si(line.c_str()+14);
+            std::istringstream si(line.c_str()+14);
             si >> info.minor;
         }
         else if (line == "}")
