@@ -17,7 +17,7 @@
 #include "tse3/TimeSigTrack.h"
 #include "tse3/FileBlockParser.h"
 
-#include <strstream>
+#include <sstream>
 
 using namespace TSE3;
 
@@ -255,7 +255,7 @@ namespace
             virtual void parse(const std::string &line)
             {
                 int time, top, bottom;
-                std::istrstream si(line.c_str());
+                std::istringstream si(line);
                 si >> time;
                 si.ignore(1); // skip colon
                 si >> top;
