@@ -1,7 +1,7 @@
 /*
  * @(#)Transport.cpp 3.00 24 May 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -41,8 +41,8 @@ const Clock Transport::_minimumLookAhead = 10;
 
 Transport::Transport(Metronome *m, MidiScheduler *s)
 : _playable(0), iterator(0), flagTrack(0), recPE(0),
-  metronome(m), metronomeIterator(0), scheduler(s),
-  _midiMapper(s), _midiEcho(s),
+  metronome(m), metronomeIterator(0), _scheduler(s),
+  _midiMapper(), _midiEcho(s),
   _status(Resting), _synchro(false), _punchIn(false), _autoStop(true),
   lastScheduledClock(0), lastPollPlaybackClock(0),
   _adaptiveLookAhead(true), _lookAhead(Clock::PPQN),
@@ -51,7 +51,7 @@ Transport::Transport(Metronome *m, MidiScheduler *s)
   transportLeadIn(Clock::PPQN/4)
 {
     metronomeIterator = metronome->iterator(0);
-    Listener<MidiSchedulerListener>::attachTo(scheduler);
+    Listener<MidiSchedulerListener>::attachTo(_scheduler);
 }
 
 
@@ -168,7 +168,7 @@ void Transport::play(Playable *p, Clock start)
     PlayableIterator *pi = _startPanic.iterator(0);
     while (pi->more())
     {
-        scheduler->tx(*(*pi));
+        _scheduler->tx(*(*pi));
         callback_MidiOut((*pi)->data);
         ++(*pi);
     }
@@ -179,12 +179,12 @@ void Transport::play(Playable *p, Clock start)
     // Start playing
     if (_synchro)
     {
-        scheduler->moveTo(start);
+        _scheduler->moveTo(start);
         _status = SynchroPlaying;
     }
     else
     {
-        scheduler->start(start-transportLeadIn);
+        _scheduler->start(start-transportLeadIn);
         _status = Playing;
     }
 
@@ -244,7 +244,7 @@ void Transport::record(Playable *p, Clock start, PhraseEdit *pe,
     PlayableIterator *pi = _startPanic.iterator(0);
     while (pi->more())
     {
-        scheduler->tx(*(*pi));
+        _scheduler->tx(*(*pi));
         callback_MidiOut((*pi)->data);
         ++(*pi);
     }
@@ -255,12 +255,12 @@ void Transport::record(Playable *p, Clock start, PhraseEdit *pe,
     // Start recording
     if (_synchro)
     {
-        scheduler->moveTo(start);
+        _scheduler->moveTo(start);
         _status = SynchroRecording;
     }
     else
     {
-        scheduler->start(start-transportLeadIn);
+        _scheduler->start(start-transportLeadIn);
         _status = Recording;
     }
 
@@ -272,7 +272,7 @@ void Transport::stop()
 {
     if (_status == Resting)
     {
-        if (scheduler->clock() > 0) scheduler->moveTo(0);
+        if (_scheduler->clock() > 0) _scheduler->moveTo(0);
         return;
     }
 
@@ -281,15 +281,13 @@ void Transport::stop()
         punchInFilter->setStatus(punchInStatus);
     }
 
-    _status = Resting;
-    scheduler->stop();
-    stopPlayback();
+    stopPlayback(lastScheduledClock);
 
     // Play Panic object
     PlayableIterator *pi = _endPanic.iterator(0);
     while (pi->more())
     {
-        scheduler->tx(*(*pi));
+        _scheduler->tx(*(*pi));
         callback_MidiOut((*pi)->data);
         ++(*pi);
     }
@@ -309,7 +307,7 @@ void Transport::ff(bool strong)
 void Transport::ffFlag()
 {
     if (!flagTrack) return;
-    Clock now = scheduler->clock();
+    Clock now = _scheduler->clock();
     size_t index = flagTrack->index(now);
     if ((*flagTrack)[index].time < now || index == flagTrack->size()) return;
     ++index;
@@ -329,7 +327,7 @@ void Transport::rew(bool strong)
 void Transport::rewFlag()
 {
     if (!flagTrack) return;
-    Clock now = scheduler->clock();
+    Clock now = _scheduler->clock();
     int index = flagTrack->index(now);
     Clock moveTo;
     if (index > 0 || (*flagTrack)[0].time < now)
@@ -355,7 +353,7 @@ void Transport::shiftBy(Clock shiftBy)
         // or we may never send these note offs.
         while (!noteOffBuffer.empty())
         {
-            scheduler->tx(noteOffBuffer.top().data);
+            _scheduler->tx(noteOffBuffer.top().data);
             // mixer_process
             // callback ?
             noteOffBuffer.pop();
@@ -365,7 +363,7 @@ void Transport::shiftBy(Clock shiftBy)
         moveTo -= moveTo % Clock::PPQN;
         if (moveTo < 0) moveTo = 0;
 
-        scheduler->moveTo(lastScheduledClock, moveTo);
+        _scheduler->moveTo(lastScheduledClock, moveTo);
         lastScheduledClock = moveTo;
         if (iterator)
         {
@@ -375,11 +373,11 @@ void Transport::shiftBy(Clock shiftBy)
     }
     else if (_status == Resting)
     {
-        Clock moveTo = scheduler->clock() + shiftBy;
+        Clock moveTo = _scheduler->clock() + shiftBy;
         moveTo -= moveTo % Clock::PPQN;
         if (moveTo < 0) moveTo = 0;
 
-        scheduler->moveTo(moveTo);
+        _scheduler->moveTo(moveTo);
     }
 }
 
@@ -387,29 +385,29 @@ void Transport::shiftBy(Clock shiftBy)
 void Transport::poll()
 {
     // MIDI input
-    while (scheduler->eventWaiting() || injectedMidiCommand.status)
+    while (_scheduler->eventWaiting() || injectedMidiCommand.status)
     {
         // If we're in a synchro mode, start transport
         if (_status == SynchroPlaying)
         {
-            scheduler->start(lastScheduledClock);
+            _scheduler->start(lastScheduledClock);
             _status = Playing;
         }
         else if (_status == SynchroRecording)
         {
-            scheduler->start(lastScheduledClock);
+            _scheduler->start(lastScheduledClock);
             _status = Recording;
         }
 
         MidiEvent e;
         if (injectedMidiCommand.status)
         {
-            e = MidiEvent(injectedMidiCommand, scheduler->clock());
+            e = MidiEvent(injectedMidiCommand, _scheduler->clock());
             injectedMidiCommand = MidiCommand();
         }
         else
         {
-            e = scheduler->rx();
+            e = _scheduler->rx();
         }
         _midiEcho.echo(e);
         callback_MidiIn(e.data);
@@ -442,7 +440,7 @@ void Transport::pollPlayback()
      * mode _playable has to point to a Playable object.
      */
 
-    Clock now = scheduler->clock();
+    Clock now = _scheduler->clock();
     if (_adaptiveLookAhead)
     {
         _lookAhead = (now - lastPollPlaybackClock)*4 + (_lookAhead/2);
@@ -525,7 +523,7 @@ void Transport::pollPlayback()
                      * MidiCommand_NoteOff in a buffer to be sent later.
                      */
                     e = _filter.filter(e);
-                    scheduler->tx(e);
+                    _scheduler->tx(e);
                     callback_MidiOut(e.data);
                     if (e.data.status == MidiCommand_NoteOn)
                     {
@@ -552,10 +550,10 @@ void Transport::pollPlayback()
                                 MidiEvent off = noteOffBuffer.top();
                                 noteOffBuffer.pop();
                                 off.time = e.time;
-                                scheduler->tx(off);
+                                _scheduler->tx(off);
                             }
 
-                            scheduler->moveTo(e.time, e.offTime);
+                            _scheduler->moveTo(e.time, e.offTime);
                             /*
                              * We return from here since we'll be reentered
                              * through update with a new time frame. We can
@@ -565,8 +563,7 @@ void Transport::pollPlayback()
                         }
                         case MidiCommand_TSE_Meta_Tempo:
                         {
-                            scheduler->setTempo(e.data.data2,
-                                                e.time);
+                            _scheduler->setTempo(e.data.data2, e.time);
                             break;
                         }
                         case MidiCommand_TSE_Meta_TimeSig:
@@ -612,13 +609,16 @@ void Transport::pollPlayback()
 }
 
 
-void Transport::stopPlayback()
+void Transport::stopPlayback(Clock stopTime)
 {
+    _status = Resting;
+    _scheduler->stop(stopTime);
+
     // empty the tx buffer somehow?
     while (!noteOffBuffer.empty())
     {
         const MidiEvent &e = noteOffBuffer.top();
-        scheduler->tx(e.data);
+        _scheduler->tx(e.data);
         noteOffBuffer.pop();
     }
     delete iterator;
@@ -695,7 +695,7 @@ void Transport::handleMidiSchedulerEvent()
 {
     if (_status != Resting)
     {
-        Clock newTime = scheduler->clock();
+        Clock newTime = _scheduler->clock();
         if (iterator) iterator->moveTo(newTime);
         metronomeIterator->moveTo(newTime);
     }
@@ -735,8 +735,9 @@ void Transport::Notifier_Deleted(Metronome *)
 
 void Transport::Notifier_Deleted(MidiScheduler *)
 {
-    scheduler = 0;
+    _scheduler = 0;
     std::cerr << "TSE3: MidiScheduler deleted whilst in use by Transport\n";
+    // XXX very bad things will now happen
 }
 
 
