@@ -1,7 +1,7 @@
 /*
  * @(#)Transport.h 3.00 25 May 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -105,6 +105,14 @@ namespace TSE3
              */
             void detachCallback(TransportCallback *c);
 
+            /**
+             * Returns the @ref MidiScheduler that this Transport object
+             * is using.
+             *
+             * @return MidiScheduler in use
+             */
+            MidiScheduler *scheduler() const { return _scheduler; }
+
             /**
              * @ref MidiFilter that affects how all @ref MidiEvents
              * are sent from the Transport object. You can use this to set
@@ -301,7 +309,7 @@ namespace TSE3
              * @param filter    The filter for punch-in track (or 0).
              */
             void record(Playable *p, Clock startTime,
-                        PhraseEdit *pe, MidiFilter *filter);
+                        PhraseEdit *pe, MidiFilter *filter = 0);
 
             /**
              * Stop playback.
@@ -538,7 +546,7 @@ namespace TSE3
              * Flushes the scheduler buffer and sends any pending
              * MidiCommand_NoteOffs immediately.
              */
-            void stopPlayback();
+            void stopPlayback(Clock stopTime);
 
             /**
              * Used by ff/rew methods.
@@ -575,7 +583,7 @@ namespace TSE3
                                             noteOffBuffer;
             Metronome                      *metronome;
             PlayableIterator               *metronomeIterator;
-            MidiScheduler                  *scheduler;
+            MidiScheduler                  *_scheduler;
             MidiFilter                      _filter;
             Panic                           _startPanic;
             Panic                           _endPanic;
