@@ -21,7 +21,7 @@
 #include "tse3/util/Song.h"
 
 #include <utility>
-#include <function.h>
+#include <functional>
 
 using namespace TSE3;
 using namespace TSE3::Cmd;
