@@ -5,7 +5,7 @@
 #include "tse3/file/XML.h"
 #include "tse3/DisplayParams.h"
 
-#include <strstream>
+#include <sstream>
 
 void TSE3::File::write(XmlFileWriter &writer, TSE3::DisplayParams &dp)
 {
@@ -14,12 +14,11 @@ void TSE3::File::write(XmlFileWriter &writer, TSE3::DisplayParams &dp)
     writer.element("Style", dp.style());
     {
         // This will be a stringstream
-        char buffer[256];
-        std::ostrstream ev(buffer, 256);
+        std::ostringstream ev;
         int r, g, b;
         dp.colour(r, g, b);
-        ev << r << "," << g << "," << b << std::ends;
-        writer.element("Colour", buffer);
+        ev << r << "," << g << "," << b;
+        writer.element("Colour", ev.str());
     }
     if (dp.style() == TSE3::DisplayParams::PresetColour)
     {
