@@ -5,7 +5,7 @@
 #include "tse3/file/XML.h"
 #include "tse3/FlagTrack.h"
 
-#include <strstream>
+#include <sstream>
 
 void TSE3::File::write(XmlFileWriter &writer, TSE3::FlagTrack &ft)
 {
@@ -15,9 +15,8 @@ void TSE3::File::write(XmlFileWriter &writer, TSE3::FlagTrack &ft)
     for (size_t n = 0; n < ft.size(); ++n)
     {
         // This will be a stringstream
-        char buffer[256];
-        std::ostrstream ev(buffer, 256);
-        ev << ft[n].time << ":" << ft[n].data.title() << std::ends;
-        writer.element("Event", buffer);
+        std::ostringstream ev;
+        ev << ft[n].time << ":" << ft[n].data.title();
+        writer.element("Event", ev.str());
     }
 }
