@@ -6,7 +6,7 @@
 #include "tse3/PhraseList.h"
 #include "tse3/Phrase.h"
 
-#include <strstream>
+#include <sstream>
 
 void TSE3::File::write(XmlFileWriter &writer, TSE3::PhraseList &pl)
 {
@@ -30,8 +30,7 @@ void TSE3::File::write(XmlFileWriter &writer, TSE3::Phrase &p)
     for (size_t n = 0; n < p.size(); ++n)
     {
         // This will be a stringstream
-        char buffer[256];
-        std::ostrstream ev(buffer, 256);
+        std::ostringstream ev;
         ev << p[n].time << ":"
            << p[n].data.status << "/"
            << p[n].data.data1 << "/"
@@ -48,7 +47,6 @@ void TSE3::File::write(XmlFileWriter &writer, TSE3::Phrase &p)
                << p[n].offData.channel << "/"
                << p[n].offData.port;
         }
-        ev << std::ends;
-        writer.element("Event", buffer);
+        writer.element("Event", ev.str());
     }
 }
