@@ -5,7 +5,7 @@
 #include "tse3/file/XML.h"
 #include "tse3/TempoTrack.h"
 
-#include <strstream>
+#include <sstream>
 
 void TSE3::File::write(XmlFileWriter &writer, TSE3::TempoTrack &tt)
 {
@@ -17,9 +17,8 @@ void TSE3::File::write(XmlFileWriter &writer, TSE3::TempoTrack &tt)
     for (size_t n = 0; n < tt.size(); ++n)
     {
         // This will be a stringstream
-        char buffer[256];
-        std::ostrstream ev(buffer, 256);
-        ev << tt[n].time << ":" << tt[n].data.tempo << std::ends;
-        writer.element("Event", buffer);
+        std::ostringstream ev;
+        ev << tt[n].time << ":" << tt[n].data.tempo;
+        writer.element("Event", ev.str());
     }
 }
