@@ -5,7 +5,7 @@
 #include "tse3/file/XML.h"
 #include "tse3/TimeSigTrack.h"
 
-#include <strstream>
+#include <sstream>
 
 void TSE3::File::write(XmlFileWriter &writer, TSE3::TimeSigTrack &tst)
 {
@@ -17,10 +17,9 @@ void TSE3::File::write(XmlFileWriter &writer, TSE3::TimeSigTrack &tst)
     for (size_t n = 0; n < tst.size(); ++n)
     {
         // This will be a stringstream
-        char buffer[256];
-        std::ostrstream ev(buffer, 256);
+        std::ostringstream ev;
         ev << tst[n].time << ":" << tst[n].data.top
-           << "/" << tst[n].data.bottom << std::ends;
-        writer.element("Event", buffer);
+           << "/" << tst[n].data.bottom;
+        writer.element("Event", ev.str());
     }
 }
