@@ -159,7 +159,7 @@ namespace
             void parse(const std::string &data)
             {
                 int i;
-                std::istrstream si(data.c_str());
+                std::istringstream si(data);
                 si >> i;
                 number = i;
             }
