@@ -22,7 +22,7 @@
 #include <cstddef>
 #include <string>
 #include <map>
-#include <strstream>
+#include <sstream>
 
 #include "tse3/Midi.h"
 
@@ -310,7 +310,7 @@ namespace TSE3
                 void parse(const std::string &data)
                 {
                     int i;
-                    std::istrstream si(data.c_str());
+                    std::istringstream si(data);
                     si >> i;
                     (obj->*mfun)(i);
                 }
@@ -346,7 +346,7 @@ namespace TSE3
                 void parse(const std::string &data)
                 {
                     int i;
-                    std::istrstream si(data.c_str());
+                    std::istringstream si(data);
                     si >> i;
                     (obj->*mfun)(i);
                 }
