@@ -20,7 +20,7 @@
 
 #include <fstream>
 #include <iostream>
-#include <strstream>
+#include <sstream>
 #include <algorithm>
 
 using namespace TSE3;
@@ -307,7 +307,7 @@ void Instrument::parseLine(const std::string &line, std::istream &in)
     }
     else if (line.substr(0,14) == "BankSelMethod=")
     {
-        std::istrstream si(line.c_str()+14);
+        std::istringstream si(line.c_str()+14);
         si >> _bankSelMethod;
     }
     else if (line.substr(0,6) == "Patch[")
@@ -316,7 +316,7 @@ void Instrument::parseLine(const std::string &line, std::istream &in)
         int bank = -1;
         if (bank_s != "*")
         {
-            std::istrstream si(line.c_str()+6);
+            std::istringstream si(line.c_str()+6);
             si >> bank;
         }
         std::string title(line.substr(line.find('=')+1));
@@ -331,12 +331,12 @@ void Instrument::parseLine(const std::string &line, std::istream &in)
         int bank = -1, patch = -1;
         if (bank_s != "*")
         {
-            std::istrstream si(bank_s.c_str());
+            std::istringstream si(bank_s);
             si >> bank;
         }
         if (patch_s != "*")
         {
-            std::istrstream si(patch_s.c_str());
+            std::istringstream si(patch_s);
             si >> patch;
         }
         std::string title(line.substr(line.find('=')+1));
@@ -354,12 +354,12 @@ void Instrument::parseLine(const std::string &line, std::istream &in)
         int bank = -1, patch = -1;
         if (bank_s != "*")
         {
-            std::istrstream si(bank_s.c_str());
+            std::istringstream si(bank_s);
             si >> bank;
         }
         if (patch_s != "*")
         {
-            std::istrstream si(patch_s.c_str());
+            std::istringstream si(patch_s);
             si >> patch;
         }
         std::string title(line.substr(line.find('=')+1));
@@ -521,7 +521,7 @@ void InstrumentData::load(const std::string &secname, std::istream &in)
                 {
                     int no = 0;
                     {
-                        std::istrstream si(line.c_str());
+                        std::istringstream si(line);
                         si >> no;
                     }
                     std::string title = line.substr(line.find('=')+1);
