@@ -1,7 +1,7 @@
 /*
  * @(#)listen/EventTrack.h 3.00 24 May 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -17,6 +17,8 @@
 #ifndef TSE3_LISTEN_EVENTTRACK_H
 #define TSE3_LISTEN_EVENTTRACK_H
 
+#include <cstddef>
+
 namespace TSE3
 {
     template <class etype> class EventTrack;
@@ -34,9 +36,12 @@ namespace TSE3
         public:
             typedef EventTrack<etype> notifier_type;
 
-            virtual void EventTrack_EventAltered(EventTrack<etype> *)  {}
-            virtual void EventTrack_EventInserted(EventTrack<etype> *) {}
-            virtual void EventTrack_EventErased(EventTrack<etype> *)   {}
+            virtual void EventTrack_EventAltered(EventTrack<etype> *,
+                                                 size_t /*index*/)        {}
+            virtual void EventTrack_EventInserted(EventTrack<etype> *,
+                                                  size_t /*index*/)       {}
+            virtual void EventTrack_EventErased(EventTrack<etype> *,
+                                                size_t /*index*/)         {}
     };
 }
 
