@@ -1,7 +1,7 @@
 /*
  * @(#)listen/MidiMapper.h 3.00 25 May 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -33,8 +33,10 @@ namespace TSE3
          public:
              typedef MidiMapper notifier_type;
 
-             virtual void MidiMapper_Altered
-                 (MidiMapper *, int /*channel*/, int /*port*/) {}
+             /**
+              * port == MidiCommand::NoPort means entire list has been reset.
+              */
+             virtual void MidiMapper_Altered(MidiMapper *, int /*port*/) {}
     };
 }
 
