@@ -1,7 +1,7 @@
 /*
  * @(#)listen/MidiScheduler.h 3.00 14 May 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -17,6 +17,8 @@
 #ifndef TSE3_LISTEN_SCHEDULER_H
 #define TSE3_LISTEN_SCHEDULER_H
 
+#include <cstddef>
+
 namespace TSE3
 {
     class MidiScheduler;
@@ -33,10 +35,12 @@ namespace TSE3
         public:
             typedef MidiScheduler notifier_type;
 
-            virtual void MidiScheduler_Started(MidiScheduler *) {}
-            virtual void MidiScheduler_Stopped(MidiScheduler *) {}
-            virtual void MidiScheduler_Moved(MidiScheduler *)   {}
-            virtual void MidiScheduler_Ports(MidiScheduler *)   {}
+            virtual void MidiScheduler_Started(MidiScheduler *)             {}
+            virtual void MidiScheduler_Stopped(MidiScheduler *)             {}
+            virtual void MidiScheduler_Moved(MidiScheduler *)               {}
+            virtual void MidiScheduler_TempoChanged(MidiScheduler *)        {}
+            virtual void MidiScheduler_PortAdded(MidiScheduler *, size_t)   {}
+            virtual void MidiScheduler_PortRemoved(MidiScheduler *, size_t) {}
     };
 }
 
