@@ -1,7 +1,7 @@
 /*
  * @(#)OSS.cpp 3.00 20 July 1999
  *
- * Copyright (c) 2000 Pete Goodliffe (pete.goodliffe@pace.co.uk)
+ * Copyright (c) 2000 Pete Goodliffe (pete@cthree.org)
  *
  * This file is part of TSE3 - the Trax Sequencer Engine version 3.00.
  *
@@ -17,6 +17,7 @@
 #include "tse3/plt/OSS.h"
 
 #include "tse3/Error.h"
+#include "tse3/util/MulDiv.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -2002,9 +2003,17 @@ OSSMidiScheduler::OSSMidiScheduler()
     rateDivisor = 1000/rate;
     nodevices = nosynths + nomidis;
 
-    synthinfo = new synth_info[nosynths];
-    midiinfo  = new midi_info[nomidis];
-    devices   = new OSSMidiScheduler_SynthDevice*[nosynths];
+    synthinfo  = new synth_info[nosynths];
+    midiinfo   = new midi_info[nomidis];
+    devices    = new OSSMidiScheduler_SynthDevice*[nosynths];
+    running    = new unsigned char[nodevices];
+    useRunning = new bool[nodevices];
+
+    for (size_t n = 0; n < nodevices; n++)
+    {
+        running[n] = 0;
+        useRunning[n] = true;
+    }
 
     const int verbose = 0;
     if (verbose) std::cout << nosynths << " synth devices available:\n";
@@ -2081,13 +2090,20 @@ OSSMidiScheduler::OSSMidiScheduler()
            if (verbose)
                std::cout << "MIDI device: " << n << ": " << midiinfo[n].name
                          << "(" << midiinfo[n].dev_type << ")\n";
+           if (!std::strcmp(midiinfo[n].name, "AWE Midi Emu"))
+           {
+               useRunning[n] = false;
+               if (verbose)
+                   std::cout << "  -- this device has broken OSS running "
+                             << "status support. Disabling running status\n";
+           }
        }
     }
 
-    running = new unsigned char[nodevices];
-    for (size_t n = 0; n < nodevices; n++)
+    // Now let the public API know about these devices
+    for (unsigned int n = 0; n < nodevices; ++n)
     {
-        running[n] = 0;
+        addPort(n, n >= nosynths, n); // XXX isInternal correct?
     }
 
     ioctl(seqfd, SNDCTL_SEQ_RESET);
@@ -2100,9 +2116,10 @@ OSSMidiScheduler::OSSMidiScheduler()
 
 OSSMidiScheduler::~OSSMidiScheduler()
 {
-#ifdef TSE3_WITH_OSS
     // if playing, stop first!
-    if (_running) stop(-1);
+    if (MidiScheduler::running()) stop();
+
+#ifdef TSE3_WITH_OSS
     close(seqfd);
     delete [] _seqbuf;
     delete [] midiinfo;
@@ -2111,11 +2128,12 @@ OSSMidiScheduler::~OSSMidiScheduler()
     delete [] devices;
 
     delete [] running;
+    delete [] useRunning;
 #endif
 }
 
 
-const char *OSSMidiScheduler::implementationName()
+const char *OSSMidiScheduler::impl_implementationName() const
 {
 #ifdef TSE3_WITH_OSS
     return "OSSMidiScheduler version 1.00";
@@ -2125,19 +2143,17 @@ const char *OSSMidiScheduler::implementationName()
 }
 
 
-size_t OSSMidiScheduler::ports() const
-{
-    return nodevices;
-}
-
-
-const char *OSSMidiScheduler::portName(size_t port) const
+const char *OSSMidiScheduler::impl_portName(int port) const
 {
 #ifdef TSE3_WITH_OSS
     if (isSynth(port))
+    {
         return synthinfo[port].name;
+    }
     else
+    {
         return midiinfo[port-nosynths].name;
+    }
 #else
     port = port;
     return "None";
@@ -2145,7 +2161,7 @@ const char *OSSMidiScheduler::portName(size_t port) const
 }
 
 
-const char *OSSMidiScheduler::portType(size_t port) const
+const char *OSSMidiScheduler::impl_portType(int port) const
 {
 #ifdef TSE3_WITH_OSS
     if (isSynth(port))
@@ -2170,7 +2186,7 @@ const char *OSSMidiScheduler::portType(size_t port) const
 }
 
 
-bool OSSMidiScheduler::portReadable(size_t port) const
+bool OSSMidiScheduler::impl_portReadable(int port) const
 {
 #ifdef TSE3_WITH_OSS
     return isMidi(port);
@@ -2181,7 +2197,7 @@ bool OSSMidiScheduler::portReadable(size_t port) const
 }
 
 
-bool OSSMidiScheduler::portWriteable(size_t /*port*/) const
+bool OSSMidiScheduler::impl_portWriteable(int /*port*/) const
 {
 #ifdef TSE3_WITH_OSS
     return true;
@@ -2191,7 +2207,7 @@ bool OSSMidiScheduler::portWriteable(size_t /*port*/) const
 }
 
 
-void OSSMidiScheduler::tx(MidiCommand mc)
+void OSSMidiScheduler::impl_tx(MidiCommand mc)
 {
     tx(mc, true);
 }
@@ -2204,14 +2220,14 @@ void OSSMidiScheduler::tx(MidiCommand mc, bool outOfBand)
     //     << mc.status << ":" << mc.channel << ":"
     //     << mc.data1 << ":" << mc.data2 << ")\n";
 
-    if (mc.port >= nodevices || mc.status == MidiCommand_Invalid) return;
+    if (mc.port >= (int)nodevices || mc.status == MidiCommand_Invalid) return;
 
     if (isMidi(mc.port))
     {
         // MIDI output: easy
         mc.port -= nosynths;
         unsigned char status = (mc.status<<4) + mc.channel;
-        if (status != running[mc.port])
+        if (!useRunning[mc.port] || status != running[mc.port])
         {
             SEQ_MIDIOUT(mc.port, status);
             running[mc.port] = status;
@@ -2275,38 +2291,26 @@ void OSSMidiScheduler::tx(MidiCommand mc, bool outOfBand)
 }
 
 
-void OSSMidiScheduler::start(const Clock s)
+void OSSMidiScheduler::impl_start(const Clock start)
 {
-    if (!_running)
-    {
-        startClock = s;
-        lastTxTime = s;
-        time       = 0;
-        // set tempo ???
+    lastTxTime = start;
+    time       = 0;
+    // set tempo ???
 #ifdef TSE3_WITH_OSS
-        SEQ_START_TIMER();
-        seqbuf_dump();
+    SEQ_START_TIMER();
+    seqbuf_dump();
 #endif
-        _running = true;
-        notify(&MidiSchedulerListener::MidiScheduler_Started);
-    }
+    clockStarted(start);
 }
 
 
-void OSSMidiScheduler::stop(Clock t)
+void OSSMidiScheduler::impl_stop(Clock t)
 {
-    if (!_running) return;
-
     if (t != -1)
     {
 #ifdef TSE3_WITH_OSS
         SEQ_WAIT_TIME(clockToMs(t)/rateDivisor);
 #endif
-        restingClock = t;
-    }
-    else
-    {
-        restingClock = clock();
     }
 #ifdef TSE3_WITH_OSS
     SEQ_STOP_TIMER();
@@ -2319,44 +2323,28 @@ void OSSMidiScheduler::stop(Clock t)
     }
     //ioctl(seqfd, SNDCTL_SEQ_SYNC);
 #endif
-    _running = false;
-    notify(&MidiSchedulerListener::MidiScheduler_Stopped);
+    clockStopped(t);
 }
 
 
-void OSSMidiScheduler::moveTo(const Clock moveTime, const Clock newTime)
+void OSSMidiScheduler::impl_moveTo(const Clock moveTime, const Clock newTime)
 {
-    if (_running)
-    {
-        startClock -= moveTime - newTime;
-    }
-    else
-    {
-        restingClock = newTime;
-    }
     lastTxTime = newTime;
-    notify(&MidiSchedulerListener::MidiScheduler_Moved);
+    clockMoved(moveTime, newTime);
 }
 
 
-Clock OSSMidiScheduler::clock()
+Clock OSSMidiScheduler::impl_clock()
 {
-    if (_running)
-    {
-        int centi = 0;
+    int centi = 0;
 #ifdef TSE3_WITH_OSS
-        ioctl(seqfd, SNDCTL_SEQ_GETTIME, &centi);
+    ioctl(seqfd, SNDCTL_SEQ_GETTIME, &centi);
 #endif
-        return msToClock(centi*rateDivisor);
-    }
-    else
-    {
-        return restingClock;
-    }
+    return msToClock(centi*rateDivisor);
 }
 
 
-int OSSMidiScheduler::msecs()
+int OSSMidiScheduler::impl_msecs()
 {
     int centi = 0;
 #ifdef TSE3_WITH_OSS
@@ -2366,25 +2354,14 @@ int OSSMidiScheduler::msecs()
 }
 
 
-void OSSMidiScheduler::setTempo(int newTempo, Clock changeTime)
+void OSSMidiScheduler::impl_setTempo(int newTempo, Clock changeTime)
 {
-    if (newTempo <= 0) return;
-
-    /*
-     * NOTE: startClock holds the scheduler clock at hardware time '0' -
-     * by altering the timeline by changing tempo, we have to work out
-     * a new value for startClock to make subseequent time calculations
-     * consistent.
-     */
-
-    startClock = changeTime
-               - Impl::muldiv(newTempo, changeTime-startClock, _tempo);
-    _tempo = newTempo;
-
 #ifdef TSE3_WITH_OSS
     SEQ_SET_TEMPO(newTempo); // XXX ? is this necessary
     seqbuf_dump();
 #endif
+
+    tempoChanged(newTempo, changeTime);
 }
 
 
@@ -2457,25 +2434,24 @@ void OSSMidiScheduler::readInput()
 }
 
 
-bool OSSMidiScheduler::eventWaiting()
+bool OSSMidiScheduler::impl_eventWaiting()
 {
     readInput();
     return input;
 }
 
 
-MidiEvent OSSMidiScheduler::rx()
+MidiEvent OSSMidiScheduler::impl_rx()
 {
     readInput();
     if (!input) return MidiEvent();
     MidiEvent e(command, time);
     input = false;
-    remoteControl(e);
     return e;
 }
 
 
-void OSSMidiScheduler::tx(MidiEvent e)
+void OSSMidiScheduler::impl_tx(MidiEvent e)
 {
 #ifdef TSE3_WITH_OSS
     if (e.time > lastTxTime)
@@ -2490,9 +2466,11 @@ void OSSMidiScheduler::tx(MidiEvent e)
 }
 
 
-void OSSMidiScheduler::txSysEx(const unsigned char * /*data*/, size_t /*size*/)
+void OSSMidiScheduler::impl_txSysEx(int /*port*/,
+                                    const unsigned char * /*data*/,
+                                    size_t /*size*/)
 {
-    // TODO
+    // TODO XXX
     std::cerr << "TSE3: (OSS) OSSMidiScheduler::txSysEx not implemented\n";
 }
 
@@ -2540,33 +2518,3 @@ void OSSMidiScheduler::setGusPatchesDirectory(const std::string &dir)
     OSSMidiScheduler_GUSDevice::setPatchesDirectory(dir);
 }
 
-
-/******************************************************************************
- * OSSMidiSchedulerFactory class
- *****************************************************************************/
-
-OSSMidiSchedulerFactory::OSSMidiSchedulerFactory()
-{
-}
-
-
-OSSMidiSchedulerFactory::~OSSMidiSchedulerFactory()
-{
-}
-
-
-OSSMidiScheduler *OSSMidiSchedulerFactory::createScheduler()
-{
-    try
-    {
-        OSSMidiScheduler *ms = new OSSMidiScheduler();
-        if (0) std::cout << "Created new OSSMidiScheduler successfully\n";
-        return ms;
-    }
-    catch (...)
-    {
-        std::cerr << "TSE3: Failed to create an OSSMidiScheduler\n";
-        throw;
-    }
-}
-
