@@ -16,7 +16,7 @@
 
 #include "tse3/util/NoteNumber.h"
 
-#include <strstream>
+#include <sstream>
 
 using namespace TSE3;
 
@@ -46,10 +46,9 @@ std::string Util::numberToNote(int note)
         dest.append("-");
 
         {
-            char buffer[5];
-            std::ostrstream o(buffer, 5);
-            o << note/12 << std::ends;
-            dest.append(buffer);
+            std::ostringstream o;
+            o << note/12;
+            dest.append(o.str());
         }
     }
 
@@ -81,7 +80,7 @@ int Util::noteToNumber(const std::string &src)
     while (src[n] == '#' || src[n] == 'b' || src[n] == '-') ++n;
 
     int octave = 0;
-    std::istrstream i(src.c_str()+n);
+    std::istringstream i(src.c_str()+n);
     i >> octave;
 
     note += octave*12;
